+
+ {selectedSnippet.docLink && (
+ }>
+
+ {selectedSnippet.docLink.label}
+
+
+ )}
- }>
-
+ }>
+
About CLI
diff --git a/apps/studio/components/layouts/SQLEditorLayout/SQLEditorNavV2/SQLEditorTreeViewItem.tsx b/apps/studio/components/layouts/SQLEditorLayout/SQLEditorNavV2/SQLEditorTreeViewItem.tsx
index 5536305da67..7635f8045d4 100644
--- a/apps/studio/components/layouts/SQLEditorLayout/SQLEditorNavV2/SQLEditorTreeViewItem.tsx
+++ b/apps/studio/components/layouts/SQLEditorLayout/SQLEditorNavV2/SQLEditorTreeViewItem.tsx
@@ -411,7 +411,7 @@ export const SQLEditorTreeViewItem = ({
onFocusCapture={(e) => e.stopPropagation()}
>
- Download as migration file
+ Export query
)}
{onSelectDelete !== undefined && isOwner && (
diff --git a/e2e/studio/features/sql-editor.spec.ts b/e2e/studio/features/sql-editor.spec.ts
index 21a302d20a5..44f2a6500ca 100644
--- a/e2e/studio/features/sql-editor.spec.ts
+++ b/e2e/studio/features/sql-editor.spec.ts
@@ -786,11 +786,11 @@ hello world`)
await expect(page.getByText('result found')).toBeVisible()
await searchBar.fill('') // clear search bar
// download as migration file
await privateSnippetSection
.getByTitle(sqlSnippetName, { exact: true })
.click({ button: 'right' })
- await page.getByRole('menuitem', { name: 'Download as migration file' }).click()
+ await page.getByRole('menuitem', { name: 'Export query' }).click()
await expect(page.getByText('supabase migration new')).toBeVisible()
await page.getByRole('button', { name: 'Close' }).click()
@@ -786,11 +786,11 @@ hello world`)
await expect(page.getByText('result found')).toBeVisible()
await searchBar.fill('') // clear search bar
- // download as migration file
+ // export query as migration file
await privateSnippetSection
.getByTitle(sqlSnippetName, { exact: true })